package com.eco.plugin.xx.zcgjsync.utils;

import com.eco.plugin.xx.zcgjsync.bean.OrgBean;
import com.eco.plugin.xx.zcgjsync.config.PluginSimpleConfig;
import com.eco.plugin.xx.zcgjsync.kit.DepartmentServiceKit;
import com.fr.decision.authority.data.Department;

/**
 * 机构操作类
 */
public class OrgUtils {
    private static String success = "S";
    private static String fail = "F";
    private static String duplicate = "添加机构失败，已存在相同的机构名称";
    private static String unknown = "未知异常";
    private static String successMsg = "操作成功";
    private static String notExist = "您操作的机构不存在";
    private static String authFail = "鉴权失败";

    public static String operOrg(String xml,String token){
        PluginSimpleConfig psc = PluginSimpleConfig.getInstance();
        OrgBean orgBean = getOrgBean(xml);
        try {
            AuthUtils.auth(token,System.currentTimeMillis(), psc);
        } catch (Exception e) {
            return getResultXml(orgBean.getID(),fail,authFail+";"+e.getMessage());
        }

        String operType = orgBean.getFROMOPERTYPE();

        DepartmentServiceKit kit = DepartmentServiceKit.getInstance();
        //新增或启用
        if("1".equals(operType) || "4".equals(operType)){
            return addOrg(orgBean,kit);
        }

        //修改
        if("2".equals(operType)){
            return updateOrg(orgBean,kit);
        }

        //停用，相当于删除
        if("3".equals(operType)){
            return deleteOrg(orgBean,kit);
        }

        return getResultXml(orgBean.getID(),fail,"未识别的操作类型FROMOPERTYPE:"+operType);
    }

    /**
     * 删除机构
     * @param orgBean
     * @param kit
     * @return
     */
    private static String deleteOrg(OrgBean orgBean, DepartmentServiceKit kit){
        String orgid = orgBean.getIU_CODE();

        try {
            Department department = kit.getByid(orgid);

            if(department == null || Utils.isNullStr(department.getId())){
                return getResultXml(orgBean.getID(),fail,notExist);
            }

            kit.deleteDepartment(orgid);
        } catch (Exception e) {
            return getResultXml(orgBean.getID(),fail,unknown+e.getMessage());
        }

        return getResultXml(orgBean.getID(),success,successMsg);
    }

    /**
     * 修改机构
     * @param orgBean
     * @param kit
     * @return
     */
    private static String updateOrg(OrgBean orgBean, DepartmentServiceKit kit){
        String orgid = orgBean.getIU_CODE();
        String pid = orgBean.getIU_LSSJDW_ID();
        String orgName = orgBean.getIU_FULLNAME();

        try {
            Department department = kit.getByid(orgid);

            if(department == null || Utils.isNullStr(department.getId())){
                return getResultXml(orgBean.getID(),fail,notExist);
            }

            kit.editDepartment(orgid,orgName,pid);
        } catch (Exception e) {
            return getResultXml(orgBean.getID(),fail,unknown+e.getMessage());
        }

        return getResultXml(orgBean.getID(),success,successMsg);
    }

    /**
     * 添加机构
     * @param orgBean
     * @param kit
     * @return
     */
    private static String addOrg(OrgBean orgBean, DepartmentServiceKit kit){
        String orgid = orgBean.getIU_CODE();
        String pid = orgBean.getIU_LSSJDW_ID();
        String orgName = orgBean.getIU_FULLNAME();

        try {
            Department department = kit.getByid(orgid);

            if(department != null && !Utils.isNullStr(department.getId())){
                return getResultXml(orgBean.getID(),fail,duplicate);
            }

            kit.addDepartment(orgid,pid,orgName);
        } catch (Exception e) {
            return getResultXml(orgBean.getID(),fail,unknown+e.getMessage());
        }

        return getResultXml(orgBean.getID(),success,successMsg);
    }

    /**
     * 获取返回报文
     * @param id
     * @param status
     * @param msg
     * @return
     */
    private static String getResultXml(String id,String status,String msg){
        String resultXml = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n" +
                "<document>\n" +
                " <info>\n" +
                " <id>#id</id>\n" +
                " <status>#status</status>\n" +
                " <type>1</type>\n" +
                " <mesg>#msg</mesg>\n" +
                " </info>\n" +
                "</document>";

        return resultXml.replace("#id",id).replace("#status",status).replace("#msg",msg);
    }

    /**
     * 从xml报文解析OrgBean实体
     * @param xmltext
     * @return
     */
    private static OrgBean getOrgBean(String xmltext){
        String ID = xmltext.substring(xmltext.indexOf("<ID>")+4,xmltext.indexOf("</ID>"));
        String FROMOPERTYPE = xmltext.substring(xmltext.indexOf("<FROMOPERTYPE>")+14,xmltext.indexOf("</FROMOPERTYPE>"));
        String STATUS = xmltext.substring(xmltext.indexOf("<STATUS>")+8,xmltext.indexOf("</STATUS>"));
        String IU_CODE = xmltext.substring(xmltext.indexOf("<IU_CODE>")+9,xmltext.indexOf("</IU_CODE>"));
        String IU_FULLNAME = xmltext.substring(xmltext.indexOf("<IU_FULLNAME>")+13,xmltext.indexOf("</IU_FULLNAME>"));
        String IU_LSSJDW_ID = xmltext.substring(xmltext.indexOf("<IU_LSSJDW_ID>")+14,xmltext.indexOf("</IU_LSSJDW_ID>"));

        OrgBean ob = new OrgBean();
        ob.setID(ID);
        ob.setFROMOPERTYPE(FROMOPERTYPE);
        ob.setSTATUS(STATUS);
        ob.setIU_CODE(IU_CODE);
        ob.setIU_FULLNAME(IU_FULLNAME);
        ob.setIU_LSSJDW_ID(IU_LSSJDW_ID);

        return ob;
    }
}


